@@ -1,13 +1,3 @@
-.onLoad <- function(lib, pkg){
-if(capabilities("X11")) {
-grDevices::X11.options(type="Xlib")
-cat("X11-type set to Xlib\n")
-}
-if(capabilities("aqua")) grDevices::quartz.options(type="native")
-invisible(NULL)
-}
-
-
 #########################################################################
 #
 #   binning in 1D -- 3D (adapted from binning function in package sm
@@ -106,7 +96,7 @@ list(yy=t(yy),ind=ind)
         d0 <- d%/%2 + 1
         gd <- seq(0, 1, length = d0)
         if (2 * d0 == d + 1)
-            gd <- c(gd, -gd[d0:2],)
+            gd <- c(gd, -gd[d0:2])
         else gd <- c(gd, -gd[(d0 - 1):2])
         gd/2/h*d
     }
@@ -244,7 +234,7 @@ list(yy=t(yy),ind=ind)
         d0 <- d%/%2 + 1
         gd <- seq(0, 1, length = d0)
         if (2 * d0 == d + 1)
-            gd <- c(gd, -gd[d0:2],)
+            gd <- c(gd, -gd[d0:2])
         else gd <- c(gd, -gd[(d0 - 1):2])
         gd
     }
@@ -590,7 +580,7 @@ list(yy=t(yy),ind=ind)
         d0 <- d%/%2 + 1
         gd <- seq(0, 1, length = d0)
         if (2 * d0 == d + 1)
-            gd <- c(gd, -gd[d0:2],)
+            gd <- c(gd, -gd[d0:2])
         else gd <- c(gd, -gd[(d0 - 1):2])
         gd
     }
